All Classes and Interfaces

Class
Description
Base configuration class for Redis based SessionRepository implementations.
 
Ensures that Redis Keyspace events for Generic commands and Expired events are enabled.
Ensures that Redis Keyspace events for Generic commands and Expired events are enabled.
Allows specifying a strategy for configuring and validating Redis using a Reactive connection.
Allows specifying a strategy for configuring and validating Redis.
Add this annotation to an @Configuration class to expose the SessionRepositoryFilter as a bean named springSessionRepositoryFilter and backed by RedisSessionRepository.
Add this annotation to an @Configuration class to expose the SessionRepositoryFilter as a bean named springSessionRepositoryFilter and backed by RedisIndexedSessionRepository.
Add this annotation to an Configuration class to expose the WebSessionManager as a bean named webSessionManager and backed by Reactive Redis.
Add this annotation to an @Configuration class to expose the WebSessionManager as a bean named webSessionManager and backed by Reactive Redis.
A ReactiveSessionRepository that is implemented using Spring Data's ReactiveRedisOperations.
A ReactiveSessionRepository that is implemented using Spring Data's ReactiveRedisOperations.
Exposes the SessionRepositoryFilter as a bean named springSessionRepositoryFilter backed by RedisSessionRepository.
Exposes the SessionRepositoryFilter as a bean named springSessionRepositoryFilter backed by RedisIndexedSessionRepository.
A SessionRepository that is implemented using Spring Data's RedisOperations.
Exposes the WebSessionManager as a bean named webSessionManager backed by ReactiveRedisIndexedSessionRepository.
An interface for storing RedisIndexedSessionRepository.RedisSession instances with their expected expiration time.
A Function that converts a Map representing Redis hash to a MapSession.
A SessionRepository implementation that uses Spring Data's RedisOperations to store sessions is Redis.
Exposes the WebSessionManager as a bean named webSessionManager.
Uses a sorted set to store the expiration times for sessions.
Qualifier annotation for a RedisConnectionFactory to be injected in RedisIndexedSessionRepository.
Annotation used to inject the Redis accessor used by Spring Session's Redis session repository.